# GestureControlMouseScroll
Gesture Control of Mouse and Scroll using Mediapipe and OpenCV
This code allows you to move your cursor and scroll the screen with your finger tips.
The mediapipe library detects one of your hands and creates a map of landmarks. It then detects the number of fingers up.
In case your index finger is up, your cursor will be moved according to your index finger tip.
Clicking is realized via retracting your index finger. You can scroll down the screen by retracting your index and middle finger simultaneously.

![image](https://github.com/BierschneiderEmanuel/GestureControlMouseScroll/assets/77926785/d7e0f04e-d4af-4cf8-a706-44bf1e308fc3)
